==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/enums/ReplicationProtectedItemOperation.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

public enum class ReplicationProtectedItemOperation(
    public val javaValue:
    com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation,
) :
    ConvertibleToJava<com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation> {
    ReverseReplicate(com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation.ReverseReplicate),
    Commit(com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation.Commit),
    PlannedFailover(com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation.PlannedFailover),
    UnplannedFailover(com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation.UnplannedFailover),
    DisableProtection(com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation.DisableProtection),
    TestFailover(com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation.TestFailover),
    TestFailoverCleanup(com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation.TestFailoverCleanup),
    Failback(com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation.Failback),
    FinalizeFailback(com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation.FinalizeFailback),
    CancelFailover(com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation.CancelFailover),
    ChangePit(com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation.ChangePit),
    RepairReplication(com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation.RepairReplication),
    SwitchProtection(com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation.SwitchProtection),
    CompleteMigration(com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation.CompleteMigration),
    ;

    override fun toJava():
        com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation = javaValue

    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation):
            ReplicationProtectedItemOperation =
            ReplicationProtectedItemOperation.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/enums/ReplicationProtectedItemOperation.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

public enum class ReplicationProtectedItemOperation(
    public val javaValue: com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation,
) :
    ConvertibleToJava<com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation> {
    ReverseReplicate(com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation.ReverseReplicate),
    Commit(com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation.Commit),
    PlannedFailover(com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation.PlannedFailover),
    UnplannedFailover(com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation.UnplannedFailover),
    DisableProtection(com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation.DisableProtection),
    TestFailover(com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation.TestFailover),
    TestFailoverCleanup(com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation.TestFailoverCleanup),
    Failback(com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation.Failback),
    FinalizeFailback(com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation.FinalizeFailback),
    CancelFailover(com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation.CancelFailover),
    ChangePit(com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation.ChangePit),
    RepairReplication(com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation.RepairReplication),
    SwitchProtection(com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation.SwitchProtection),
    CompleteMigration(com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation.CompleteMigration),
    ;

    override fun toJava(): com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation = javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.recoveryservices.enums.ReplicationProtectedItemOperation): ReplicationProtectedItemOperation =
            ReplicationProtectedItemOperation.values().first { it.javaValue == javaType }
    }
}
